api.reports.v1.test_helpers.template package — Argus-Toolbelt 1.0 documentation

# api.reports.v1.test_helpers.template package

## Submodules

## api.reports.v1.test_helpers.template.add module

`api.reports.v1.test_helpers.template.add.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 403

`api.reports.v1.test_helpers.template.add.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 404

`api.reports.v1.test_helpers.template.add.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 200

`api.reports.v1.test_helpers.template.add.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 401

## api.reports.v1.test_helpers.template.get_template module

`api.reports.v1.test_helpers.template.get_template.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 403

`api.reports.v1.test_helpers.template.get_template.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 404

`api.reports.v1.test_helpers.template.get_template.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 200

`api.reports.v1.test_helpers.template.get_template.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 401

## api.reports.v1.test_helpers.template.list_templates module

`api.reports.v1.test_helpers.template.list_templates.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 403

`api.reports.v1.test_helpers.template.list_templates.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 404

`api.reports.v1.test_helpers.template.list_templates.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 200

`api.reports.v1.test_helpers.template.list_templates.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template, respond with HTTP 401

## api.reports.v1.test_helpers.template.search_templates module

`api.reports.v1.test_helpers.template.search_templates.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/search, respond with HTTP 403

`api.reports.v1.test_helpers.template.search_templates.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/search, respond with HTTP 404

`api.reports.v1.test_helpers.template.search_templates.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/search, respond with HTTP 200

`api.reports.v1.test_helpers.template.search_templates.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/search, respond with HTTP 401

## api.reports.v1.test_helpers.template.update module

`api.reports.v1.test_helpers.template.update.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 403

`api.reports.v1.test_helpers.template.update.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 404

`api.reports.v1.test_helpers.template.update.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 200

`api.reports.v1.test_helpers.template.update.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/template/w+, respond with HTTP 401

## Module contents